@@ -108,6 +108,9 @@ GType clutter_pick_mode_get_type (void) G_GNUC_CONST;
 GType clutter_swipe_direction_get_type (void) G_GNUC_CONST;
 #define CLUTTER_TYPE_SWIPE_DIRECTION (clutter_swipe_direction_get_type())
 
+GType clutter_pan_axis_get_type (void) G_GNUC_CONST;
+#define CLUTTER_TYPE_PAN_AXIS (clutter_pan_axis_get_type())
+
 GType clutter_table_alignment_get_type (void) G_GNUC_CONST;
 #define CLUTTER_TYPE_TABLE_ALIGNMENT (clutter_table_alignment_get_type())
 
@@ -138,6 +141,24 @@ GType clutter_content_gravity_get_type (void) G_GNUC_CONST;
 GType clutter_scaling_filter_get_type (void) G_GNUC_CONST;
 #define CLUTTER_TYPE_SCALING_FILTER (clutter_scaling_filter_get_type())
 
+GType clutter_orientation_get_type (void) G_GNUC_CONST;
+#define CLUTTER_TYPE_ORIENTATION (clutter_orientation_get_type())
+
+GType clutter_scroll_mode_get_type (void) G_GNUC_CONST;
+#define CLUTTER_TYPE_SCROLL_MODE (clutter_scroll_mode_get_type())
+
+GType clutter_grid_position_get_type (void) G_GNUC_CONST;
+#define CLUTTER_TYPE_GRID_POSITION (clutter_grid_position_get_type())
+
+GType clutter_content_repeat_get_type (void) G_GNUC_CONST;
+#define CLUTTER_TYPE_CONTENT_REPEAT (clutter_content_repeat_get_type())
+
+GType clutter_step_mode_get_type (void) G_GNUC_CONST;
+#define CLUTTER_TYPE_STEP_MODE (clutter_step_mode_get_type())
+
+GType clutter_zoom_axis_get_type (void) G_GNUC_CONST;
+#define CLUTTER_TYPE_ZOOM_AXIS (clutter_zoom_axis_get_type())
+
 /* enumerations from "./clutter-image.h" */
 GType clutter_image_error_get_type (void) G_GNUC_CONST;
 #define CLUTTER_TYPE_IMAGE_ERROR (clutter_image_error_get_type())
